@@ -50,7 +50,7 @@ import operator
 import re
 import contextlib
 import io
-from distutils import dir_util
+import distutils.dir_util
 import importlib
 import itertools
 
@@ -216,16 +216,6 @@ class Path(text_type):
         """
         return cls
 
-    @classmethod
-    def _always_unicode(cls, path):
-        """
-        Ensure the path as retrieved from a Python API, such as :func:`os.listdir`,
-        is a proper Unicode string.
-        """
-        if PY3 or isinstance(path, text_type):
-            return path
-        return path.decode(sys.getfilesystemencoding(), 'surrogateescape')
-
     # --- Special Python methods.
 
     def __repr__(self):
@@ -279,6 +269,9 @@ class Path(text_type):
     def __exit__(self, *_):
         os.chdir(self._old_dir)
 
+    def __fspath__(self):
+        return self
+
     @classmethod
     def getcwd(cls):
         """ Return the current working directory as a path object.
@@ -535,7 +528,7 @@ class Path(text_type):
             pattern = '*'
         return [
             self / child
-            for child in map(self._always_unicode, os.listdir(self))
+            for child in os.listdir(self)
             if self._next_class(child).fnmatch(pattern)
         ]
 
@@ -1392,8 +1385,12 @@ class Path(text_type):
             self.copytree(stage, symlinks, *args, **kwargs)
             # now copy everything from the stage directory using
             #  the semantics of dir_util.copy_tree
-            dir_util.copy_tree(stage, dst, preserve_symlinks=symlinks,
-                update=update)
+            distutils.dir_util.copy_tree(
+                stage,
+                dst,
+                preserve_symlinks=symlinks,
+                update=update,
+            )
 
     #
     # --- Special stuff from os
@@ -1710,15 +1707,3 @@ class CaseInsensitivePattern(text_type):
     @property
     def normcase(self):
         return __import__('ntpath').normcase
-
-########################
-# Backward-compatibility
-class path(Path):
-    def __new__(cls, *args, **kwargs):
-        msg = "path is deprecated. Use Path instead."
-        warnings.warn(msg, DeprecationWarning)
-        return Path.__new__(cls, *args, **kwargs)
-
-
-__all__ += ['path']
-########################
